pub enum FindError {
Pe(Error),
Bad8Path,
NotFound,
NoRootPath,
UnDataEntry,
UnDirectory,
}Expand description
Find error.
Variants
Pe(Error)
An error happened when reading the underlying resources.
This error indicates the resources are corrupt.
Bad8Path
The resources work with UTF-16 path names.
For this to work the given path must be valid unicode for the path comparison to make sense.
This error means the given path contained non-unicode parts.
NotFound
The requested data entry or directory doesn’t exist.
NoRootPath
Paths from the resources root must start with a / or \.
UnDataEntry
Encountered a data entry when expecting a directory.
This error means the given path contained a directory name which is actually a data entry.
UnDirectory
Encountered a directory when expecting a data entry.
Implementations