pub enum Name<'a> {
Id(u32),
Wide(&'a [u16]),
Str(&'a str),
}Expand description
Represents a resource name.
Variants
Id(u32)
Resource ID.
Technically allows u32 ids, but some Windows APIs will be unable to use resources with an id which isn’t u16.
Wide(&'a [u16])
UTF-16 named resource.
Str(&'a str)
UTF-8 named resource.
This variant is used when accepting user input and will be interpreted liberally when compared against other names: When prefixed with ‘#’ the string is parsed as a u32 and compared to resource ids. Otherwise compares against wide strings by doing an unicode aware case sensitive comparison.
Implementations