Directory

Struct Directory 

pub struct Directory<'a> { /* private fields */ }
Directory.

Implementations

Source

impl<'a> Directory<'a>

pub fn get(&self, name: Name<'_>) -> Result<Entry<'a>, FindError>

Looks up the entry by name.

pub fn get_data(&self, name: Name<'_>) -> Result<DataEntry<'a>, FindError>

Looks up the data entry by name.

pub fn get_dir(&self, name: Name<'_>) -> Result<Directory<'a>, FindError>

Looks up the directory by name.

pub fn first(&self) -> Result<Entry<'a>, FindError>

Gets the first entry.

pub fn first_data(&self) -> Result<DataEntry<'a>, FindError>

Gets the first data entry.

pub fn first_dir(&self) -> Result<Directory<'a>, FindError>

Gets the first directory.

Source

impl<'a> Directory<'a>

pub fn find<P: AsRef<Path> + ?Sized>( &self, path: &P, ) -> Result<Entry<'a>, FindError>

Finds a file or directory by its path.

pub fn find_data<P: AsRef<Path> + ?Sized>( &self, path: &P, ) -> Result<DataEntry<'a>, FindError>

Finds a file by its path.

pub fn find_dir<P: AsRef<Path> + ?Sized>( &self, path: &P, ) -> Result<Directory<'a>, FindError>

Finds a directory by its path.

Source

impl<'a> Directory<'a>

pub fn resources(&self) -> Resources<'a>

Gets the resources.

pub fn image(&self) -> &'a IMAGE_RESOURCE_DIRECTORY

Gets the underlying resource directory image.

pub fn entries( &self, ) -> Entries<'a, impl Clone + FnMut(&'a IMAGE_RESOURCE_DIRECTORY_ENTRY) -> DirectoryEntry<'a>>

Gets the directory entries.

pub fn named_entries( &self, ) -> Entries<'a, impl Clone + FnMut(&'a IMAGE_RESOURCE_DIRECTORY_ENTRY) -> DirectoryEntry<'a>>

Gets the named entries in this directory.

Note that while it would be a violation of the format spec, there’s no strict safety guarantee that these are only named entries.

pub fn id_entries( &self, ) -> Entries<'a, impl Clone + FnMut(&'a IMAGE_RESOURCE_DIRECTORY_ENTRY) -> DirectoryEntry<'a>>

Gets the id entries in this directory.

Note that while it would be a violation of the format spec, there’s no strict safety guarantee that these are only id entries.

pub fn fsck(&self) -> Result<()>

Filesystem consistency check.

Simply walks the filesystem checking all references are valid.